---
id: f-c589
status: open
deps: []
links: []
created: 2026-01-12T15:02:19Z
type: epic
priority: 2
assignee: legout
external-ref: openspec:2026-01-12-consolidate-path-normalization
---
# Consolidate path normalization

